==> proguard1.5.1.tar.gz: proguard1.5.1/src/proguard/classfile/visitor/NamedFieldVisitor.java <==
/* $Id: NamedFieldVisitor.java,v 1.7 2002/09/07 16:05:13 eric Exp $
 *
 * ProGuard -- obfuscation and shrinking package for Java class files.
 *
 * Copyright (C) 2002 Eric Lafortune (eric@graphics.cornell.edu)
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package proguard.classfile.visitor;

import proguard.classfile.*;


/**
 * This class visits ProgramMemberInfo objects referring to fields, identified by
 * a name and descriptor pair.
 *
 * @author Eric Lafortune
 */
public class NamedFieldVisitor implements ClassFileVisitor
{
    private MemberInfoVisitor memberInfoVisitor;
    private String            name;
    private String            descriptor;


    public NamedFieldVisitor(MemberInfoVisitor memberInfoVisitor,
                             String            name,
                             String            descriptor)
    {
        this.memberInfoVisitor = memberInfoVisitor;
        this.name              = name;
        this.descriptor        = descriptor;
    }


    public void visitProgramClassFile(ProgramClassFile programClassFile)
    {
        programClassFile.fieldAccept(memberInfoVisitor, name, descriptor);
    }


    public void visitLibraryClassFile(LibraryClassFile libraryClassFile)
    {
        libraryClassFile.fieldAccept(memberInfoVisitor, name, descriptor);
    }
}

==> proguard3.2.tar.gz: proguard3.2/src/proguard/classfile/visitor/NamedFieldVisitor.java <==
/* $Id: NamedFieldVisitor.java,v 1.11 2004/12/11 16:35:23 eric Exp $
 *
 * ProGuard -- shrinking, optimization, and obfuscation of Java class files.
 *
 * Copyright (c) 2002-2004 Eric Lafortune (eric@graphics.cornell.edu)
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
package proguard.classfile.visitor;

import proguard.classfile.*;


/**
 * This class visits ProgramMemberInfo objects referring to fields, identified by
 * a name and descriptor pair.
 *
 * @author Eric Lafortune
 */
public class NamedFieldVisitor implements ClassFileVisitor
{
    private String            name;
    private String            descriptor;
    private MemberInfoVisitor memberInfoVisitor;


    public NamedFieldVisitor(String            name,
                             String            descriptor,
                             MemberInfoVisitor memberInfoVisitor)
    {
        this.name              = name;
        this.descriptor        = descriptor;
        this.memberInfoVisitor = memberInfoVisitor;
    }


    public void visitProgramClassFile(ProgramClassFile programClassFile)
    {
        programClassFile.fieldAccept(name, descriptor, memberInfoVisitor);
    }


    public void visitLibraryClassFile(LibraryClassFile libraryClassFile)
    {
        libraryClassFile.fieldAccept(name, descriptor, memberInfoVisitor);
    }
}
